# Examples

To understand the design philosophy behind SciANN, please check our review paper: [https://arxiv.org/abs/2005.08803](https://arxiv.org/abs/2005.08803)

A great repository of examples is being created on SciANN's github repository: [SciANN-applications](https://github.com/sciann/sciann-applications)

A simple example can be found in sciann installation folder: [example-fitting-1D](https://www.sciann.com/examples/example-fitting-1d/)

- Simple linear and quadratic regression: [SciANN-Regression.ipynb](https://github.com/sciann/sciann-applications/blob/master/SciANN-Linear-Quadratic-Regression/SciANN-Regression.ipynb)

- Curve-fitting using neural networks: [SciANN-NN-Regression.ipynb](https://github.com/sciann/sciann-applications/tree/master/SciANN-NN-Regression)

- Application to linear-elasticity: [SciANN-SolidMechanics](https://github.com/sciann/sciann-applications/tree/master/SciANN-SolidMechanics)


---

{{autogenerated}}
